<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-revisions?lang_cible=fr_fem
// ** ne pas modifier le fichier **

return [

	// R
	'revisions_description' => 'Suivi des modifications des objets éditoriaux',
	'revisions_slogan' => 'Suivi des modifications des objets éditoriaux',
];
